# Names in __all__ with no definition:
#   Qt3DAnimation
#   Qt3DCore
#   Qt3DExtras
#   Qt3DInput
#   Qt3DLogic
#   Qt3DRender
#   QtCharts
#   QtConcurrent
#   QtCore
#   QtDataVisualization
#   QtGui
#   QtHelp
#   QtLocation
#   QtMacExtras
#   QtMultimedia
#   QtMultimediaWidgets
#   QtNetwork
#   QtOpenGL
#   QtOpenGLFunctions
#   QtPositioning
#   QtPrintSupport
#   QtQml
#   QtQuick
#   QtQuickControls2
#   QtQuickWidgets
#   QtRemoteObjects
#   QtScript
#   QtScriptTools
#   QtScxml
#   QtSensors
#   QtSerialPort
#   QtSql
#   QtSvg
#   QtTest
#   QtTextToSpeech
#   QtUiTools
#   QtWebChannel
#   QtWebEngine
#   QtWebEngineCore
#   QtWebEngineWidgets
#   QtWebSockets
#   QtWidgets
#   QtX11Extras
#   QtXml
#   QtXmlPatterns
__version__: str
__version_info__: tuple[int, int, float, str, str]



import PySide2.QtCore
import PySide2.QtGui
import _typeshed
import collections.abc
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class Qt3DCore(shiboken2.Object):
    class ChangeFlag:
        AllChanges: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        CallbackTriggered: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        CommandRequested: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        ComponentAdded: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        ComponentRemoved: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        NodeCreated: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        NodeDeleted: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        PropertyUpdated: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        PropertyValueAdded: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        PropertyValueRemoved: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> Qt3DCore.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...

    class ChangeFlags:
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __and__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __invert__(self) -> Qt3DCore.ChangeFlags: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...
        def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.ChangeFlags: ...

    class QAbstractAspect(PySide2.QtCore.QObject):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
        def rootEntityId(self) -> Qt3DCore.QNodeId: ...
        def unregisterBackendType(self, arg__1: PySide2.QtCore.QMetaObject) -> None: ...

    class QAbstractSkeleton(Qt3DCore.QNode):
        jointCountChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def jointCount(self) -> int: ...

    class QArmature(Qt3DCore.QComponent):
        skeletonChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DCore.QArmature.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., shareableChanged: typing.Callable = ..., skeleton: Qt3DCore.QAbstractSkeleton = ..., skeletonChanged: typing.Callable = ...) -> None: ...
        def setSkeleton(self, skeleton: Qt3DCore.QAbstractSkeleton) -> None: ...
        def skeleton(self) -> Qt3DCore.QAbstractSkeleton: ...

    class QAspectEngine(PySide2.QtCore.QObject):
        class RunMode:
            Automatic: typing.ClassVar[Qt3DCore.QAspectEngine.RunMode] = ...
            Manual: typing.ClassVar[Qt3DCore.QAspectEngine.RunMode] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QAspectEngine.RunMode: ...
        Automatic: typing.ClassVar[Qt3DCore.QAspectEngine.RunMode] = ...
        Manual: typing.ClassVar[Qt3DCore.QAspectEngine.RunMode] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
        def aspects(self) -> typing.List[Qt3DCore.QAbstractAspect]: ...
        def executeCommand(self, command: str) -> typing.Any: ...
        def processFrame(self) -> None: ...
        @typing.overload
        def registerAspect(self, name: str) -> None: ...
        @typing.overload
        def registerAspect(self, aspect: Qt3DCore.QAbstractAspect) -> None: ...
        def runMode(self) -> Qt3DCore.QAspectEngine.RunMode: ...
        def setRunMode(self, mode: Qt3DCore.QAspectEngine.RunMode) -> None: ...
        @typing.overload
        def unregisterAspect(self, name: str) -> None: ...
        @typing.overload
        def unregisterAspect(self, aspect: Qt3DCore.QAbstractAspect) -> None: ...

    class QAspectJob(shiboken2.Object):
        def __init__(self) -> None: ...
        def run(self) -> None: ...

    class QBackendNode(shiboken2.Object):
        class Mode:
            ReadOnly: typing.ClassVar[Qt3DCore.QBackendNode.Mode] = ...
            ReadWrite: typing.ClassVar[Qt3DCore.QBackendNode.Mode] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QBackendNode.Mode: ...
        ReadOnly: typing.ClassVar[Qt3DCore.QBackendNode.Mode] = ...
        ReadWrite: typing.ClassVar[Qt3DCore.QBackendNode.Mode] = ...
        def __init__(self, mode: Qt3DCore.QBackendNode.Mode = ...) -> None: ...
        def isEnabled(self) -> bool: ...
        def mode(self) -> Qt3DCore.QBackendNode.Mode: ...
        def peerId(self) -> Qt3DCore.QNodeId: ...
        def setEnabled(self, enabled: bool) -> None: ...

    class QComponent(Qt3DCore.QNode):
        addedToEntity: typing.ClassVar[PySide2.QtCore.Signal] = ...
        removedFromEntity: typing.ClassVar[PySide2.QtCore.Signal] = ...
        shareableChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DCore.QComponent.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., isShareable: bool = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., shareableChanged: typing.Callable = ...) -> None: ...
        def entities(self) -> typing.List[Qt3DCore.QEntity]: ...
        def isShareable(self) -> bool: ...
        def setShareable(self, isShareable: bool) -> None: ...

    class QComponentAddedChange(Qt3DCore.QSceneChange):
        @typing.overload
        def __init__(self, entity: Qt3DCore.QEntity, component: Qt3DCore.QComponent) -> None: ...
        @typing.overload
        def __init__(self, component: Qt3DCore.QComponent, entity: Qt3DCore.QEntity) -> None: ...
        def componentId(self) -> Qt3DCore.QNodeId: ...
        def componentMetaObject(self) -> PySide2.QtCore.QMetaObject: ...
        def entityId(self) -> Qt3DCore.QNodeId: ...

    class QComponentRemovedChange(Qt3DCore.QSceneChange):
        @typing.overload
        def __init__(self, entity: Qt3DCore.QEntity, component: Qt3DCore.QComponent) -> None: ...
        @typing.overload
        def __init__(self, component: Qt3DCore.QComponent, entity: Qt3DCore.QEntity) -> None: ...
        def componentId(self) -> Qt3DCore.QNodeId: ...
        def componentMetaObject(self) -> PySide2.QtCore.QMetaObject: ...
        def entityId(self) -> Qt3DCore.QNodeId: ...

    class QDynamicPropertyUpdatedChange(Qt3DCore.QPropertyUpdatedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def propertyName(self) -> PySide2.QtCore.QByteArray: ...
        def setPropertyName(self, name: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> None: ...
        def setValue(self, value: typing.Any) -> None: ...
        def value(self) -> typing.Any: ...

    class QEntity(Qt3DCore.QNode):
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DCore.QEntity.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ...) -> None: ...
        def addComponent(self, comp: Qt3DCore.QComponent) -> None: ...
        def components(self) -> typing.List[Qt3DCore.QComponent]: ...
        def parentEntity(self) -> Qt3DCore.QEntity: ...
        def removeComponent(self, comp: Qt3DCore.QComponent) -> None: ...

    class QJoint(Qt3DCore.QNode):
        inverseBindMatrixChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        nameChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationXChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationYChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationZChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        translationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DCore.QJoint.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., inverseBindMatrix: PySide2.QtGui.QMatrix4x4 = ..., inverseBindMatrixChanged: typing.Callable = ..., name: str = ..., nameChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., rotation: PySide2.QtGui.QQuaternion = ..., rotationChanged: typing.Callable = ..., rotationX: float = ..., rotationXChanged: typing.Callable = ..., rotationY: float = ..., rotationYChanged: typing.Callable = ..., rotationZ: float = ..., rotationZChanged: typing.Callable = ..., scale: PySide2.QtGui.QVector3D = ..., scaleChanged: typing.Callable = ..., translation: PySide2.QtGui.QVector3D = ..., translationChanged: typing.Callable = ...) -> None: ...
        def addChildJoint(self, joint: Qt3DCore.QJoint) -> None: ...
        def childJoints(self) -> typing.List[Qt3DCore.QJoint]: ...
        def inverseBindMatrix(self) -> PySide2.QtGui.QMatrix4x4: ...
        def name(self) -> str: ...
        def removeChildJoint(self, joint: Qt3DCore.QJoint) -> None: ...
        def rotation(self) -> PySide2.QtGui.QQuaternion: ...
        def rotationX(self) -> float: ...
        def rotationY(self) -> float: ...
        def rotationZ(self) -> float: ...
        def scale(self) -> PySide2.QtGui.QVector3D: ...
        def setInverseBindMatrix(self, inverseBindMatrix: PySide2.QtGui.QMatrix4x4) -> None: ...
        def setName(self, name: str) -> None: ...
        def setRotation(self, rotation: PySide2.QtGui.QQuaternion) -> None: ...
        def setRotationX(self, rotationX: float) -> None: ...
        def setRotationY(self, rotationY: float) -> None: ...
        def setRotationZ(self, rotationZ: float) -> None: ...
        def setScale(self, scale: PySide2.QtGui.QVector3D) -> None: ...
        def setToIdentity(self) -> None: ...
        def setTranslation(self, translation: PySide2.QtGui.QVector3D) -> None: ...
        def translation(self) -> PySide2.QtGui.QVector3D: ...

    class QNode(PySide2.QtCore.QObject):
        class PropertyTrackingMode:
            DontTrackValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
            TrackAllValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
            TrackFinalValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QNode.PropertyTrackingMode: ...
        DontTrackValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
        TrackAllValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
        TrackFinalValues: typing.ClassVar[Qt3DCore.QNode.PropertyTrackingMode] = ...
        defaultPropertyTrackingModeChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        enabledChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        nodeDestroyed: typing.ClassVar[PySide2.QtCore.Signal] = ...
        parentChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DCore.QNode.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ...) -> None: ...
        def blockNotifications(self, block: bool) -> bool: ...
        def childNodes(self) -> typing.List[Qt3DCore.QNode]: ...
        def clearPropertyTracking(self, propertyName: str) -> None: ...
        def clearPropertyTrackings(self) -> None: ...
        def defaultPropertyTrackingMode(self) -> Qt3DCore.QNode.PropertyTrackingMode: ...
        def id(self) -> Qt3DCore.QNodeId: ...
        def isEnabled(self) -> bool: ...
        def notificationsBlocked(self) -> bool: ...
        def parentNode(self) -> Qt3DCore.QNode: ...
        def propertyTracking(self, propertyName: str) -> Qt3DCore.QNode.PropertyTrackingMode: ...
        def setDefaultPropertyTrackingMode(self, mode: Qt3DCore.QNode.PropertyTrackingMode) -> None: ...
        def setEnabled(self, isEnabled: bool) -> None: ...
        @typing.overload
        def setParent(self, parent: Qt3DCore.QNode) -> None: ...
        @typing.overload
        def setParent(self, parent: typing.Union[PySide2.QtCore.QObject, None]) -> None: ...
        def setPropertyTracking(self, propertyName: str, trackMode: Qt3DCore.QNode.PropertyTrackingMode) -> None: ...

    class QNodeCommand(Qt3DCore.QSceneChange):
        def __init__(self, id: Qt3DCore.QNodeId) -> None: ...
        def commandId(self) -> int: ...
        def data(self) -> typing.Any: ...
        def inReplyTo(self) -> int: ...
        def name(self) -> str: ...
        def setData(self, data: typing.Any) -> None: ...
        def setName(self, name: str) -> None: ...
        def setReplyToCommandId(self, id: int) -> None: ...

    class QNodeCreatedChangeBase(Qt3DCore.QSceneChange):
        def __init__(self, node: Qt3DCore.QNode) -> None: ...
        def isNodeEnabled(self) -> bool: ...
        def parentId(self) -> Qt3DCore.QNodeId: ...

    class QNodeDestroyedChange(Qt3DCore.QSceneChange):
        def __init__(self, node: Qt3DCore.QNode, subtreeIdsAndTypes: typing.List[Qt3DCore.QNodeIdTypePair]) -> None: ...
        def subtreeIdsAndTypes(self) -> typing.List[Qt3DCore.QNodeIdTypePair]: ...

    class QNodeId(shiboken2.Object):
        @typing.overload
        def __init__(self, QNodeId: Qt3DCore.QNodeId) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        @classmethod
        def createId(cls) -> Qt3DCore.QNodeId: ...
        def id(self) -> int: ...
        def isNull(self) -> bool: ...
        def __bool__(self) -> bool: ...
        def __copy__(self) -> None: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __ne__(self, other: object) -> bool: ...

    class QNodeIdTypePair(shiboken2.Object):
        id: _typeshed.Incomplete
        type: _typeshed.Incomplete
        @typing.overload
        def __init__(self, _id: Qt3DCore.QNodeId, _type: PySide2.QtCore.QMetaObject) -> None: ...
        @typing.overload
        def __init__(self, QNodeIdTypePair: Qt3DCore.QNodeIdTypePair) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        def __copy__(self) -> None: ...

    class QPropertyNodeAddedChange(Qt3DCore.QStaticPropertyValueAddedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId, node: Qt3DCore.QNode) -> None: ...
        def addedNodeId(self) -> Qt3DCore.QNodeId: ...

    class QPropertyNodeRemovedChange(Qt3DCore.QStaticPropertyValueRemovedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId, node: Qt3DCore.QNode) -> None: ...
        def removedNodeId(self) -> Qt3DCore.QNodeId: ...

    class QPropertyUpdatedChange(Qt3DCore.QStaticPropertyUpdatedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def setValue(self, value: typing.Any) -> None: ...
        def value(self) -> typing.Any: ...

    class QPropertyUpdatedChangeBase(Qt3DCore.QSceneChange):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...

    class QPropertyValueAddedChange(Qt3DCore.QStaticPropertyValueAddedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def addedValue(self) -> typing.Any: ...
        def setAddedValue(self, value: typing.Any) -> None: ...

    class QPropertyValueAddedChangeBase(Qt3DCore.QSceneChange):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...

    class QPropertyValueRemovedChange(Qt3DCore.QStaticPropertyValueRemovedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def removedValue(self) -> typing.Any: ...
        def setRemovedValue(self, value: typing.Any) -> None: ...

    class QPropertyValueRemovedChangeBase(Qt3DCore.QSceneChange):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...

    class QSceneChange(shiboken2.Object):
        class DeliveryFlag:
            BackendNodes: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
            DeliverToAll: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
            Nodes: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __invert__(self) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...

        class DeliveryFlags:
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __invert__(self) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QSceneChange.DeliveryFlags: ...
        BackendNodes: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
        DeliverToAll: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
        Nodes: typing.ClassVar[Qt3DCore.QSceneChange.DeliveryFlag] = ...
        def __init__(self, type: Qt3DCore.ChangeFlag, subjectId: Qt3DCore.QNodeId) -> None: ...
        def deliveryFlags(self) -> typing.Union[Qt3DCore.QSceneChange.DeliveryFlags, Qt3DCore.QSceneChange.DeliveryFlag]: ...
        def setDeliveryFlags(self, flags: typing.Union[Qt3DCore.QSceneChange.DeliveryFlags, Qt3DCore.QSceneChange.DeliveryFlag]) -> None: ...
        def subjectId(self) -> Qt3DCore.QNodeId: ...
        def type(self) -> Qt3DCore.ChangeFlag: ...

    class QSkeleton(Qt3DCore.QAbstractSkeleton):
        rootJointChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., defaultPropertyTrackingMode: Qt3DCore.QSkeleton.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., jointCount: int = ..., jointCountChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., rootJoint: Qt3DCore.QJoint = ..., rootJointChanged: typing.Callable = ...) -> None: ...
        def rootJoint(self) -> Qt3DCore.QJoint: ...
        def setRootJoint(self, rootJoint: Qt3DCore.QJoint) -> None: ...

    class QSkeletonLoader(Qt3DCore.QAbstractSkeleton):
        class Status:
            Error: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
            NotReady: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
            Ready: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
            values: typing.ClassVar[dict] = ...
            name: _typeshed.Incomplete
            @classmethod
            def __init__(cls, *args, **kwargs) -> None: ...
            def __add__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __and__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __bool__(self) -> bool: ...
            def __eq__(self, other: object) -> bool: ...
            def __ge__(self, other: object) -> bool: ...
            def __gt__(self, other: object) -> bool: ...
            def __hash__(self) -> int: ...
            def __index__(self) -> int: ...
            def __int__(self) -> int: ...
            def __le__(self, other: object) -> bool: ...
            def __lt__(self, other: object) -> bool: ...
            def __mul__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __ne__(self, other: object) -> bool: ...
            def __or__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __pos__(self): ...
            def __radd__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __rand__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __rmul__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __ror__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __rsub__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __rxor__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __sub__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
            def __xor__(self, other: typing.SupportsInt) -> Qt3DCore.QSkeletonLoader.Status: ...
        Error: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
        NotReady: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
        Ready: typing.ClassVar[Qt3DCore.QSkeletonLoader.Status] = ...
        createJointsEnabledChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rootJointChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        sourceChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        statusChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        @typing.overload
        def __init__(self, source: PySide2.QtCore.QUrl, parent: typing.Union[Qt3DCore.QNode, None] = ..., createJointsEnabled: bool = ..., createJointsEnabledChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DCore.QSkeletonLoader.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., jointCount: int = ..., jointCountChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., rootJoint: Qt3DCore.QJoint = ..., rootJointChanged: typing.Callable = ..., sourceChanged: typing.Callable = ..., status: Qt3DCore.QSkeletonLoader.Status = ..., statusChanged: typing.Callable = ...) -> None: ...
        @typing.overload
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., createJointsEnabled: bool = ..., createJointsEnabledChanged: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DCore.QSkeletonLoader.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., jointCount: int = ..., jointCountChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., rootJoint: Qt3DCore.QJoint = ..., rootJointChanged: typing.Callable = ..., source: PySide2.QtCore.QUrl = ..., sourceChanged: typing.Callable = ..., status: Qt3DCore.QSkeletonLoader.Status = ..., statusChanged: typing.Callable = ...) -> None: ...
        def isCreateJointsEnabled(self) -> bool: ...
        def rootJoint(self) -> Qt3DCore.QJoint: ...
        def setCreateJointsEnabled(self, enabled: bool) -> None: ...
        def setSource(self, source: PySide2.QtCore.QUrl) -> None: ...
        def source(self) -> PySide2.QtCore.QUrl: ...
        def status(self) -> Qt3DCore.QSkeletonLoader.Status: ...

    class QStaticPropertyUpdatedChangeBase(Qt3DCore.QPropertyUpdatedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def propertyName(self) -> bytes: ...
        def setPropertyName(self, name: bytes) -> None: ...

    class QStaticPropertyValueAddedChangeBase(Qt3DCore.QPropertyValueAddedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def propertyName(self) -> bytes: ...
        def setPropertyName(self, name: bytes) -> None: ...

    class QStaticPropertyValueRemovedChangeBase(Qt3DCore.QPropertyValueRemovedChangeBase):
        def __init__(self, subjectId: Qt3DCore.QNodeId) -> None: ...
        def propertyName(self) -> bytes: ...
        def setPropertyName(self, name: bytes) -> None: ...

    class QTransform(Qt3DCore.QComponent):
        matrixChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationXChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationYChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        rotationZChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        scale3DChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        scaleChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
        translationChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        worldMatrixChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
        def __init__(self, parent: typing.Union[Qt3DCore.QNode, None] = ..., addedToEntity: typing.Callable = ..., defaultPropertyTrackingMode: Qt3DCore.QTransform.PropertyTrackingMode = ..., defaultPropertyTrackingModeChanged: typing.Callable = ..., destroyed: typing.Callable = ..., enabled: bool = ..., enabledChanged: typing.Callable = ..., isShareable: bool = ..., matrix: PySide2.QtGui.QMatrix4x4 = ..., matrixChanged: typing.Callable = ..., nodeDestroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., parentChanged: typing.Callable = ..., removedFromEntity: typing.Callable = ..., rotation: PySide2.QtGui.QQuaternion = ..., rotationChanged: typing.Callable = ..., rotationX: float = ..., rotationXChanged: typing.Callable = ..., rotationY: float = ..., rotationYChanged: typing.Callable = ..., rotationZ: float = ..., rotationZChanged: typing.Callable = ..., scale: float = ..., scale3D: PySide2.QtGui.QVector3D = ..., scale3DChanged: typing.Callable = ..., scaleChanged: typing.Callable = ..., shareableChanged: typing.Callable = ..., translation: PySide2.QtGui.QVector3D = ..., translationChanged: typing.Callable = ..., worldMatrix: PySide2.QtGui.QMatrix4x4 = ..., worldMatrixChanged: typing.Callable = ...) -> None: ...
        @classmethod
        def fromAxes(cls, xAxis: PySide2.QtGui.QVector3D, yAxis: PySide2.QtGui.QVector3D, zAxis: PySide2.QtGui.QVector3D) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromAxesAndAngles(cls, axis1: PySide2.QtGui.QVector3D, angle1: float, axis2: PySide2.QtGui.QVector3D, angle2: float, axis3: PySide2.QtGui.QVector3D, angle3: float) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromAxesAndAngles(cls, axis1: PySide2.QtGui.QVector3D, angle1: float, axis2: PySide2.QtGui.QVector3D, angle2: float) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromAxisAndAngle(cls, x: float, y: float, z: float, angle: float) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromAxisAndAngle(cls, axis: PySide2.QtGui.QVector3D, angle: float) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromEulerAngles(cls, pitch: float, yaw: float, roll: float) -> PySide2.QtGui.QQuaternion: ...
        @typing.overload
        @classmethod
        def fromEulerAngles(cls, eulerAngles: PySide2.QtGui.QVector3D) -> PySide2.QtGui.QQuaternion: ...
        def matrix(self) -> PySide2.QtGui.QMatrix4x4: ...
        @classmethod
        def rotateAround(cls, point: PySide2.QtGui.QVector3D, angle: float, axis: PySide2.QtGui.QVector3D) -> PySide2.QtGui.QMatrix4x4: ...
        @classmethod
        def rotateFromAxes(cls, xAxis: PySide2.QtGui.QVector3D, yAxis: PySide2.QtGui.QVector3D, zAxis: PySide2.QtGui.QVector3D) -> PySide2.QtGui.QMatrix4x4: ...
        def rotation(self) -> PySide2.QtGui.QQuaternion: ...
        def rotationX(self) -> float: ...
        def rotationY(self) -> float: ...
        def rotationZ(self) -> float: ...
        def scale(self) -> float: ...
        def scale3D(self) -> PySide2.QtGui.QVector3D: ...
        def setMatrix(self, matrix: PySide2.QtGui.QMatrix4x4) -> None: ...
        def setRotation(self, rotation: PySide2.QtGui.QQuaternion) -> None: ...
        def setRotationX(self, rotationX: float) -> None: ...
        def setRotationY(self, rotationY: float) -> None: ...
        def setRotationZ(self, rotationZ: float) -> None: ...
        def setScale(self, scale: float) -> None: ...
        def setScale3D(self, scale: PySide2.QtGui.QVector3D) -> None: ...
        def setTranslation(self, translation: PySide2.QtGui.QVector3D) -> None: ...
        def translation(self) -> PySide2.QtGui.QVector3D: ...
        def worldMatrix(self) -> PySide2.QtGui.QMatrix4x4: ...
    AllChanges: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    CallbackTriggered: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    CommandRequested: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    ComponentAdded: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    ComponentRemoved: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    NodeCreated: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    NodeDeleted: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    PropertyUpdated: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    PropertyValueAdded: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    PropertyValueRemoved: typing.ClassVar[Qt3DCore.ChangeFlag] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def qHash(cls, id: Qt3DCore.QNodeId, seed: int = ...) -> int: ...
    @classmethod
    def qIdForNode(cls, node: Qt3DCore.QNode) -> Qt3DCore.QNodeId: ...



import PySide2.QtCore
import PySide2.QtGui
import PySide2.QtWidgets
import _typeshed
import collections.abc
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class QTest(shiboken2.Object):
    class KeyAction:
        Click: typing.ClassVar[QTest.KeyAction] = ...
        Press: typing.ClassVar[QTest.KeyAction] = ...
        Release: typing.ClassVar[QTest.KeyAction] = ...
        Shortcut: typing.ClassVar[QTest.KeyAction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __and__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __rand__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __ror__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __sub__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...
        def __xor__(self, other: typing.SupportsInt) -> QTest.KeyAction: ...

    class MouseAction:
        MouseClick: typing.ClassVar[QTest.MouseAction] = ...
        MouseDClick: typing.ClassVar[QTest.MouseAction] = ...
        MouseMove: typing.ClassVar[QTest.MouseAction] = ...
        MousePress: typing.ClassVar[QTest.MouseAction] = ...
        MouseRelease: typing.ClassVar[QTest.MouseAction] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __and__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __rand__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __ror__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __sub__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...
        def __xor__(self, other: typing.SupportsInt) -> QTest.MouseAction: ...

    class QBenchmarkMetric:
        AlignmentFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BitsPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BranchInstructions: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BranchMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BusCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BytesAllocated: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        BytesPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CPUCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CPUMigrations: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CPUTicks: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CachePrefetchMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CachePrefetches: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheReadMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheReads: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheReferences: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheWriteMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        CacheWrites: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        ContextSwitches: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        EmulationFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        Events: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        FramesPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        InstructionReads: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        Instructions: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        MajorPageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        MinorPageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        PageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        RefCPUCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        StalledCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        WalltimeMilliseconds: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        WalltimeNanoseconds: typing.ClassVar[QTest.QBenchmarkMetric] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __and__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __rand__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __ror__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __sub__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...
        def __xor__(self, other: typing.SupportsInt) -> QTest.QBenchmarkMetric: ...

    class QTouchEventSequence(shiboken2.Object):
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def commit(self, processEvents: bool = ...) -> None: ...
        @typing.overload
        def move(self, touchId: int, pt: PySide2.QtCore.QPoint, window: typing.Union[PySide2.QtGui.QWindow, None] = ...) -> QTest.QTouchEventSequence: ...
        @typing.overload
        def move(self, touchId: int, pt: PySide2.QtCore.QPoint, widget: typing.Union[PySide2.QtWidgets.QWidget, None] = ...) -> QTest.QTouchEventSequence: ...
        @typing.overload
        def press(self, touchId: int, pt: PySide2.QtCore.QPoint, window: typing.Union[PySide2.QtGui.QWindow, None] = ...) -> QTest.QTouchEventSequence: ...
        @typing.overload
        def press(self, touchId: int, pt: PySide2.QtCore.QPoint, widget: typing.Union[PySide2.QtWidgets.QWidget, None] = ...) -> QTest.QTouchEventSequence: ...
        @typing.overload
        def release(self, touchId: int, pt: PySide2.QtCore.QPoint, window: typing.Union[PySide2.QtGui.QWindow, None] = ...) -> QTest.QTouchEventSequence: ...
        @typing.overload
        def release(self, touchId: int, pt: PySide2.QtCore.QPoint, widget: typing.Union[PySide2.QtWidgets.QWidget, None] = ...) -> QTest.QTouchEventSequence: ...
        def stationary(self, touchId: int) -> QTest.QTouchEventSequence: ...

    class TestFailMode:
        Abort: typing.ClassVar[QTest.TestFailMode] = ...
        Continue: typing.ClassVar[QTest.TestFailMode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __and__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __rand__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __ror__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __sub__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
        def __xor__(self, other: typing.SupportsInt) -> QTest.TestFailMode: ...
    Abort: typing.ClassVar[QTest.TestFailMode] = ...
    AlignmentFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BitsPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BranchInstructions: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BranchMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BusCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BytesAllocated: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    BytesPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CPUCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CPUMigrations: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CPUTicks: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CachePrefetchMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CachePrefetches: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheReadMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheReads: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheReferences: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheWriteMisses: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    CacheWrites: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Click: typing.ClassVar[QTest.KeyAction] = ...
    ContextSwitches: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Continue: typing.ClassVar[QTest.TestFailMode] = ...
    EmulationFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Events: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    FramesPerSecond: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    InstructionReads: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Instructions: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    MajorPageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    MinorPageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    MouseClick: typing.ClassVar[QTest.MouseAction] = ...
    MouseDClick: typing.ClassVar[QTest.MouseAction] = ...
    MouseMove: typing.ClassVar[QTest.MouseAction] = ...
    MousePress: typing.ClassVar[QTest.MouseAction] = ...
    MouseRelease: typing.ClassVar[QTest.MouseAction] = ...
    PageFaults: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Press: typing.ClassVar[QTest.KeyAction] = ...
    RefCPUCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    Release: typing.ClassVar[QTest.KeyAction] = ...
    Shortcut: typing.ClassVar[QTest.KeyAction] = ...
    StalledCycles: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    WalltimeMilliseconds: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    WalltimeNanoseconds: typing.ClassVar[QTest.QBenchmarkMetric] = ...
    mouseDoubleClickInterval: typing.ClassVar[int] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    @classmethod
    def addColumnInternal(cls, id: int, name: bytes) -> None: ...
    @classmethod
    def asciiToKey(cls, ascii: int) -> PySide2.QtCore.Qt.Key: ...
    @classmethod
    def compare_ptr_helper(cls, t1: int, t2: int, actual: bytes, expected: bytes, file: bytes, line: int) -> bool: ...
    @classmethod
    def compare_string_helper(cls, t1: bytes, t2: bytes, actual: bytes, expected: bytes, file: bytes, line: int) -> bool: ...
    @classmethod
    def createTouchDevice(cls, devType: PySide2.QtGui.QTouchDevice.DeviceType = ...) -> PySide2.QtGui.QTouchDevice: ...
    @classmethod
    def currentAppName(cls) -> bytes: ...
    @classmethod
    def currentDataTag(cls) -> bytes: ...
    @classmethod
    def currentTestFailed(cls) -> bool: ...
    @classmethod
    def currentTestFunction(cls) -> bytes: ...
    @typing.overload
    @classmethod
    def ignoreMessage(cls, type: PySide2.QtCore.QtMsgType, messagePattern: PySide2.QtCore.QRegularExpression) -> None: ...
    @typing.overload
    @classmethod
    def ignoreMessage(cls, type: PySide2.QtCore.QtMsgType, message: bytes) -> None: ...
    @typing.overload
    @classmethod
    def keyClick(cls, window: PySide2.QtGui.QWindow, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyClick(cls, window: PySide2.QtGui.QWindow, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyClick(cls, widget: PySide2.QtWidgets.QWidget, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyClick(cls, widget: PySide2.QtWidgets.QWidget, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @classmethod
    def keyClicks(cls, widget: PySide2.QtWidgets.QWidget, sequence: str, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyEvent(cls, action: QTest.KeyAction, window: PySide2.QtGui.QWindow, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyEvent(cls, action: QTest.KeyAction, window: PySide2.QtGui.QWindow, ascii: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyEvent(cls, action: QTest.KeyAction, widget: PySide2.QtWidgets.QWidget, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyEvent(cls, action: QTest.KeyAction, widget: PySide2.QtWidgets.QWidget, ascii: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyPress(cls, window: PySide2.QtGui.QWindow, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyPress(cls, window: PySide2.QtGui.QWindow, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyPress(cls, widget: PySide2.QtWidgets.QWidget, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyPress(cls, widget: PySide2.QtWidgets.QWidget, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyRelease(cls, window: PySide2.QtGui.QWindow, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyRelease(cls, window: PySide2.QtGui.QWindow, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyRelease(cls, widget: PySide2.QtWidgets.QWidget, key: PySide2.QtCore.Qt.Key, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keyRelease(cls, widget: PySide2.QtWidgets.QWidget, key: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def keySequence(cls, window: PySide2.QtGui.QWindow, keySequence: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    @typing.overload
    @classmethod
    def keySequence(cls, widget: PySide2.QtWidgets.QWidget, keySequence: typing.Union[PySide2.QtGui.QKeySequence, str]) -> None: ...
    @classmethod
    def keyToAscii(cls, key: PySide2.QtCore.Qt.Key) -> int: ...
    @typing.overload
    @classmethod
    def mouseClick(cls, window: PySide2.QtGui.QWindow, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseClick(cls, widget: PySide2.QtWidgets.QWidget, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseDClick(cls, window: PySide2.QtGui.QWindow, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseDClick(cls, widget: PySide2.QtWidgets.QWidget, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseEvent(cls, action: QTest.MouseAction, window: PySide2.QtGui.QWindow, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], pos: PySide2.QtCore.QPoint, delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseEvent(cls, action: QTest.MouseAction, widget: PySide2.QtWidgets.QWidget, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], pos: PySide2.QtCore.QPoint, delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseMove(cls, window: PySide2.QtGui.QWindow, pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseMove(cls, widget: PySide2.QtWidgets.QWidget, pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mousePress(cls, window: PySide2.QtGui.QWindow, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mousePress(cls, widget: PySide2.QtWidgets.QWidget, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseRelease(cls, window: PySide2.QtGui.QWindow, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def mouseRelease(cls, widget: PySide2.QtWidgets.QWidget, button: PySide2.QtCore.Qt.MouseButton, stateKey: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier] = ..., pos: PySide2.QtCore.QPoint = ..., delay: int = ...) -> None: ...
    @classmethod
    def qCleanup(cls) -> None: ...
    @classmethod
    def qElementData(cls, elementName: bytes, metaTypeId: int) -> int: ...
    @classmethod
    def qExpectFail(cls, dataIndex: bytes, comment: bytes, mode: QTest.TestFailMode, file: bytes, line: int) -> bool: ...
    @typing.overload
    @classmethod
    def qFindTestData(cls, basepath: str, file: typing.Union[bytes, None] = ..., line: int = ..., builddir: typing.Union[bytes, None] = ...) -> str: ...
    @typing.overload
    @classmethod
    def qFindTestData(cls, basepath: bytes, file: typing.Union[bytes, None] = ..., line: int = ..., builddir: typing.Union[bytes, None] = ...) -> str: ...
    @classmethod
    def qGlobalData(cls, tagName: bytes, typeId: int) -> int: ...
    @classmethod
    def qRun(cls) -> int: ...
    @classmethod
    def qSkip(cls, message: bytes, file: bytes, line: int) -> None: ...
    @classmethod
    def qWaitForWindowActive(cls, widget: PySide2.QtWidgets.QWidget, timeout: int = ...) -> bool: ...
    @classmethod
    def qWaitForWindowExposed(cls, widget: PySide2.QtWidgets.QWidget, timeout: int = ...) -> bool: ...
    @typing.overload
    @classmethod
    def sendKeyEvent(cls, action: QTest.KeyAction, window: PySide2.QtGui.QWindow, code: PySide2.QtCore.Qt.Key, text: str, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def sendKeyEvent(cls, action: QTest.KeyAction, window: PySide2.QtGui.QWindow, code: PySide2.QtCore.Qt.Key, ascii: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def sendKeyEvent(cls, action: QTest.KeyAction, widget: PySide2.QtWidgets.QWidget, code: PySide2.QtCore.Qt.Key, text: str, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def sendKeyEvent(cls, action: QTest.KeyAction, widget: PySide2.QtWidgets.QWidget, code: PySide2.QtCore.Qt.Key, ascii: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], delay: int = ...) -> None: ...
    @classmethod
    def setBenchmarkResult(cls, result: float, metric: QTest.QBenchmarkMetric) -> None: ...
    @classmethod
    def setMainSourcePath(cls, file: bytes, builddir: typing.Union[bytes, None] = ...) -> None: ...
    @typing.overload
    @classmethod
    def simulateEvent(cls, window: PySide2.QtGui.QWindow, press: bool, code: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], text: str, repeat: bool, delay: int = ...) -> None: ...
    @typing.overload
    @classmethod
    def simulateEvent(cls, widget: PySide2.QtWidgets.QWidget, press: bool, code: int, modifier: typing.Union[PySide2.QtCore.Qt.KeyboardModifiers, PySide2.QtCore.Qt.KeyboardModifier], text: str, repeat: bool, delay: int = ...) -> None: ...
    @classmethod
    def testObject(cls) -> PySide2.QtCore.QObject: ...
    @classmethod
    def toPrettyCString(cls, unicode: bytes, length: int) -> bytes: ...
    @typing.overload
    @classmethod
    def touchEvent(cls, window: PySide2.QtGui.QWindow, device: PySide2.QtGui.QTouchDevice, autoCommit: bool = ...) -> QTest.QTouchEventSequence: ...
    @typing.overload
    @classmethod
    def touchEvent(cls, widget: PySide2.QtWidgets.QWidget, device: PySide2.QtGui.QTouchDevice, autoCommit: bool = ...) -> QTest.QTouchEventSequence: ...



import _typeshed
import collections.abc
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class QQuickStyle(shiboken2.Object):
    def __init__(self) -> None: ...
    @classmethod
    def addStylePath(cls, path: str) -> None: ...
    @classmethod
    def availableStyles(cls) -> typing.List[str]: ...
    @classmethod
    def name(cls) -> str: ...
    @classmethod
    def path(cls) -> str: ...
    @classmethod
    def setFallbackStyle(cls, style: str) -> None: ...
    @classmethod
    def setStyle(cls, style: str) -> None: ...
    @classmethod
    def stylePathList(cls) -> typing.List[str]: ...



import PySide2.QtCore
import _typeshed
import collections.abc
import shiboken2
import typing
T = typing.TypeVar('T')
import typing_extensions

class QAbstractItemModelReplica(PySide2.QtCore.QAbstractItemModel):
    initialized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def availableRoles(self) -> typing.List[int]: ...
    def columnCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def data(self, index: PySide2.QtCore.QModelIndex, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> typing.Any: ...
    def flags(self, index: PySide2.QtCore.QModelIndex) -> typing.Union[PySide2.QtCore.Qt.ItemFlags, PySide2.QtCore.Qt.ItemFlag]: ...
    def hasChildren(self, parent: PySide2.QtCore.QModelIndex = ...) -> bool: ...
    def hasData(self, index: PySide2.QtCore.QModelIndex, role: PySide2.QtCore.Qt.ItemDataRole) -> bool: ...
    def headerData(self, section: int, orientation: PySide2.QtCore.Qt.Orientation, role: PySide2.QtCore.Qt.ItemDataRole) -> typing.Any: ...
    def index(self, row: int, column: int, parent: PySide2.QtCore.QModelIndex = ...) -> PySide2.QtCore.QModelIndex: ...
    def isInitialized(self) -> bool: ...
    @typing.overload
    def parent(self, index: PySide2.QtCore.QModelIndex) -> PySide2.QtCore.QModelIndex: ...
    @typing.overload
    def parent(self) -> PySide2.QtCore.QObject: ...
    def roleNames(self) -> typing.Dict[int, PySide2.QtCore.QByteArray]: ...
    def rowCount(self, parent: PySide2.QtCore.QModelIndex = ...) -> int: ...
    def selectionModel(self) -> PySide2.QtCore.QItemSelectionModel: ...
    def setData(self, index: PySide2.QtCore.QModelIndex, value: typing.Any, role: PySide2.QtCore.Qt.ItemDataRole = ...) -> bool: ...

class QRemoteObjectAbstractPersistedStore(PySide2.QtCore.QObject):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def restoreProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> typing.List[typing.Any]: ...
    def saveProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes], values: typing.Iterable[typing.Any]) -> None: ...

class QRemoteObjectDynamicReplica(QRemoteObjectReplica):
    initialized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    notified: typing.ClassVar[PySide2.QtCore.Signal] = ...
    stateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...

class QRemoteObjectHost(QRemoteObjectHostBase):
    hostUrlChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, address: PySide2.QtCore.QUrl, registryAddress: PySide2.QtCore.QUrl = ..., allowedSchemas: QRemoteObjectHostBase.AllowedSchemas = ..., parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., hostUrl: PySide2.QtCore.QUrl = ..., hostUrlChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: typing.Any = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, address: PySide2.QtCore.QUrl, parent: typing.Union[PySide2.QtCore.QObject, None], destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., hostUrl: PySide2.QtCore.QUrl = ..., hostUrlChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: typing.Any = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., hostUrl: PySide2.QtCore.QUrl = ..., hostUrlChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: typing.Any = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    def hostUrl(self) -> PySide2.QtCore.QUrl: ...
    def setHostUrl(self, hostAddress: PySide2.QtCore.QUrl, allowedSchemas: QRemoteObjectHostBase.AllowedSchemas = ...) -> bool: ...

class QRemoteObjectHostBase(QRemoteObjectNode):
    class AllowedSchemas:
        AllowExternalRegistration: typing.ClassVar[QRemoteObjectHostBase.AllowedSchemas] = ...
        BuiltInSchemasOnly: typing.ClassVar[QRemoteObjectHostBase.AllowedSchemas] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __and__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __rand__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __rmul__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __ror__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __rsub__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __rxor__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __sub__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
        def __xor__(self, other: typing.SupportsInt) -> QRemoteObjectHostBase.AllowedSchemas: ...
    AllowExternalRegistration: typing.ClassVar[QRemoteObjectHostBase.AllowedSchemas] = ...
    BuiltInSchemasOnly: typing.ClassVar[QRemoteObjectHostBase.AllowedSchemas] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def addHostSideConnection(self, ioDevice: PySide2.QtCore.QIODevice) -> None: ...
    def disableRemoting(self, remoteObject: PySide2.QtCore.QObject) -> bool: ...
    @typing.overload
    def enableRemoting(self, model: PySide2.QtCore.QAbstractItemModel, name: str, roles: typing.List[int], selectionModel: typing.Union[PySide2.QtCore.QItemSelectionModel, None] = ...) -> bool: ...
    @typing.overload
    def enableRemoting(self, object: PySide2.QtCore.QObject, name: str = ...) -> bool: ...
    def hostUrl(self) -> PySide2.QtCore.QUrl: ...
    def proxy(self, registryUrl: PySide2.QtCore.QUrl, hostUrl: PySide2.QtCore.QUrl = ...) -> bool: ...
    def reverseProxy(self) -> bool: ...
    def setHostUrl(self, hostAddress: PySide2.QtCore.QUrl, allowedSchemas: QRemoteObjectHostBase.AllowedSchemas = ...) -> bool: ...
    def setName(self, name: str) -> None: ...

class QRemoteObjectNode(PySide2.QtCore.QObject):
    class ErrorCode:
        HostUrlInvalid: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        ListenFailed: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        MissingObjectName: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        NoError: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        NodeIsNoServer: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        OperationNotValidOnClientNode: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        ProtocolMismatch: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        RegistryAlreadyHosted: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        RegistryNotAcquired: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        ServerAlreadyCreated: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        SourceNotRegistered: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        UnintendedRegistryHosting: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __and__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __rand__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __rmul__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __ror__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __rsub__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __rxor__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __sub__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
        def __xor__(self, other: typing.SupportsInt) -> QRemoteObjectNode.ErrorCode: ...
    HostUrlInvalid: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    ListenFailed: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    MissingObjectName: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    NoError: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    NodeIsNoServer: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    OperationNotValidOnClientNode: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    ProtocolMismatch: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    RegistryAlreadyHosted: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    RegistryNotAcquired: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    ServerAlreadyCreated: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    SourceNotRegistered: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    UnintendedRegistryHosting: typing.ClassVar[QRemoteObjectNode.ErrorCode] = ...
    error: typing.ClassVar[PySide2.QtCore.Signal] = ...
    heartbeatIntervalChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    remoteObjectAdded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    remoteObjectRemoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @typing.overload
    def __init__(self, registryAddress: PySide2.QtCore.QUrl, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: QRemoteObjectAbstractPersistedStore = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: QRemoteObjectAbstractPersistedStore = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    def acquireDynamic(self, name: str) -> QRemoteObjectDynamicReplica: ...
    def acquireModel(self, name: str) -> QAbstractItemModelReplica: ...
    def addClientSideConnection(self, ioDevice: PySide2.QtCore.QIODevice) -> None: ...
    def connectToNode(self, address: PySide2.QtCore.QUrl) -> bool: ...
    def heartbeatInterval(self) -> int: ...
    def instances(self, typeName: str) -> typing.List[str]: ...
    def lastError(self) -> QRemoteObjectNode.ErrorCode: ...
    def persistedStore(self) -> QRemoteObjectAbstractPersistedStore: ...
    def registry(self) -> QRemoteObjectRegistry: ...
    def registryUrl(self) -> PySide2.QtCore.QUrl: ...
    def setHeartbeatInterval(self, interval: int) -> None: ...
    def setName(self, name: str) -> None: ...
    def setPersistedStore(self, persistedStore: QRemoteObjectAbstractPersistedStore) -> None: ...
    def setRegistryUrl(self, registryAddress: PySide2.QtCore.QUrl) -> bool: ...
    def timerEvent(self, arg__1: PySide2.QtCore.QTimerEvent) -> None: ...
    def waitForRegistry(self, timeout: int = ...) -> bool: ...

class QRemoteObjectPendingCall(shiboken2.Object):
    class Error:
        InvalidMessage: typing.ClassVar[QRemoteObjectPendingCall.Error] = ...
        NoError: typing.ClassVar[QRemoteObjectPendingCall.Error] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __and__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __rand__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __rmul__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __ror__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __rsub__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __rxor__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __sub__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
        def __xor__(self, other: typing.SupportsInt) -> QRemoteObjectPendingCall.Error: ...
    InvalidMessage: typing.ClassVar[QRemoteObjectPendingCall.Error] = ...
    NoError: typing.ClassVar[QRemoteObjectPendingCall.Error] = ...
    @typing.overload
    def __init__(self, other: QRemoteObjectPendingCall) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def error(self) -> QRemoteObjectPendingCall.Error: ...
    @classmethod
    def fromCompletedCall(cls, returnValue: typing.Any) -> QRemoteObjectPendingCall: ...
    def isFinished(self) -> bool: ...
    def returnValue(self) -> typing.Any: ...
    def waitForFinished(self, timeout: int = ...) -> bool: ...

class QRemoteObjectPendingCallWatcher(PySide2.QtCore.QObject, QRemoteObjectPendingCall):
    finished: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, call: QRemoteObjectPendingCall, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def isFinished(self) -> bool: ...
    def waitForFinished(self) -> None: ...

class QRemoteObjectRegistry(QRemoteObjectReplica):
    remoteObjectAdded: typing.ClassVar[PySide2.QtCore.Signal] = ...
    remoteObjectRemoved: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    @classmethod
    def __init__(cls, *args, **kwargs) -> None: ...
    def addSource(self, entry: typing.Tuple[str, QRemoteObjectSourceLocationInfo]) -> None: ...
    def initialize(self) -> None: ...
    def pushToRegistryIfNeeded(self) -> None: ...
    @classmethod
    def registerMetatypes(cls) -> None: ...
    def removeSource(self, entry: typing.Tuple[str, QRemoteObjectSourceLocationInfo]) -> None: ...
    def sourceLocations(self) -> typing.Dict[str, QRemoteObjectSourceLocationInfo]: ...

class QRemoteObjectRegistryHost(QRemoteObjectHostBase):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, registryAddress: PySide2.QtCore.QUrl = ..., parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., error: typing.Callable = ..., heartbeatInterval: int = ..., heartbeatIntervalChanged: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., persistedStore: typing.Any = ..., registryUrl: PySide2.QtCore.QUrl = ..., remoteObjectAdded: typing.Callable = ..., remoteObjectRemoved: typing.Callable = ...) -> None: ...
    def setRegistryUrl(self, registryUrl: PySide2.QtCore.QUrl) -> bool: ...

class QRemoteObjectReplica(PySide2.QtCore.QObject):
    class State:
        Default: typing.ClassVar[QRemoteObjectReplica.State] = ...
        SignatureMismatch: typing.ClassVar[QRemoteObjectReplica.State] = ...
        Suspect: typing.ClassVar[QRemoteObjectReplica.State] = ...
        Uninitialized: typing.ClassVar[QRemoteObjectReplica.State] = ...
        Valid: typing.ClassVar[QRemoteObjectReplica.State] = ...
        values: typing.ClassVar[dict] = ...
        name: _typeshed.Incomplete
        @classmethod
        def __init__(cls, *args, **kwargs) -> None: ...
        def __add__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __and__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __bool__(self) -> bool: ...
        def __eq__(self, other: object) -> bool: ...
        def __ge__(self, other: object) -> bool: ...
        def __gt__(self, other: object) -> bool: ...
        def __hash__(self) -> int: ...
        def __index__(self) -> int: ...
        def __int__(self) -> int: ...
        def __le__(self, other: object) -> bool: ...
        def __lt__(self, other: object) -> bool: ...
        def __mul__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __ne__(self, other: object) -> bool: ...
        def __or__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __pos__(self): ...
        def __radd__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __rand__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __rmul__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __ror__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __rsub__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __rxor__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __sub__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
        def __xor__(self, other: typing.SupportsInt) -> QRemoteObjectReplica.State: ...
    Default: typing.ClassVar[QRemoteObjectReplica.State] = ...
    SignatureMismatch: typing.ClassVar[QRemoteObjectReplica.State] = ...
    Suspect: typing.ClassVar[QRemoteObjectReplica.State] = ...
    Uninitialized: typing.ClassVar[QRemoteObjectReplica.State] = ...
    Valid: typing.ClassVar[QRemoteObjectReplica.State] = ...
    initialized: typing.ClassVar[PySide2.QtCore.Signal] = ...
    notified: typing.ClassVar[PySide2.QtCore.Signal] = ...
    stateChanged: typing.ClassVar[PySide2.QtCore.Signal] = ...
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, destroyed: typing.Callable = ..., initialized: typing.Callable = ..., node: QRemoteObjectNode = ..., notified: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ..., state: QRemoteObjectReplica.State = ..., stateChanged: typing.Callable = ...) -> None: ...
    def initialize(self) -> None: ...
    def initializeNode(self, node: QRemoteObjectNode, name: str = ...) -> None: ...
    def isInitialized(self) -> bool: ...
    def isReplicaValid(self) -> bool: ...
    def node(self) -> QRemoteObjectNode: ...
    def persistProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes], props: typing.Iterable[typing.Any]) -> None: ...
    def propAsVariant(self, i: int) -> typing.Any: ...
    def retrieveProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> typing.List[typing.Any]: ...
    def send(self, call: PySide2.QtCore.QMetaObject.Call, index: int, args: typing.Iterable[typing.Any]) -> None: ...
    def sendWithReply(self, call: PySide2.QtCore.QMetaObject.Call, index: int, args: typing.Iterable[typing.Any]) -> QRemoteObjectPendingCall: ...
    def setChild(self, i: int, arg__2: typing.Any) -> None: ...
    def setNode(self, node: QRemoteObjectNode) -> None: ...
    def setProperties(self, arg__1: typing.Iterable[typing.Any]) -> None: ...
    def state(self) -> QRemoteObjectReplica.State: ...
    def waitForSource(self, timeout: int = ...) -> bool: ...

class QRemoteObjectSettingsStore(QRemoteObjectAbstractPersistedStore):
    staticMetaObject: typing.ClassVar[PySide2.QtCore.QMetaObject] = ...
    def __init__(self, parent: typing.Union[PySide2.QtCore.QObject, None] = ..., destroyed: typing.Callable = ..., objectName: str = ..., objectNameChanged: typing.Callable = ...) -> None: ...
    def restoreProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes]) -> typing.List[typing.Any]: ...
    def saveProperties(self, repName: str, repSig: typing.Union[PySide2.QtCore.QByteArray, bytes], values: typing.Iterable[typing.Any]) -> None: ...

class QRemoteObjectSourceLocationInfo(shiboken2.Object):
    hostUrl: _typeshed.Incomplete
    typeName: _typeshed.Incomplete
    @typing.overload
    def __init__(self, typeName_: str, hostUrl_: PySide2.QtCore.QUrl) -> None: ...
    @typing.overload
    def __init__(self, QRemoteObjectSourceLocationInfo: QRemoteObjectSourceLocationInfo) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    def __copy__(self) -> None: ...
    def __eq__(self, other: object) -> bool: ...
    def __ge__(self, other: object) -> bool: ...
    def __gt__(self, other: object) -> bool: ...
    def __le__(self, other: object) -> bool: ...
    def __lshift__(self, stream: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
    def __lt__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
    def __rlshift__(self, other): ...
    def __rrshift__(self, other): ...
    def __rshift__(self, stream: PySide2.QtCore.QDataStream) -> PySide2.QtCore.QDataStream: ...
